parse

Function parse 

pub fn parse(name: &str) -> Option<Name>
Parse an emitted identifier back to the entity it names.

Returns None for identifiers the compiler did not generate from a graph entity (params, temporaries like %vals-*/%lvl-*, user identifiers).