pub struct NodeSpans {
pub defs: Vec<Range<usize>>,
pub refs: Vec<Range<usize>>,
}Expand description
The spans associated with one node, as returned by
SourceMap::node_spans.
Fields
defs: Vec<Range<usize>>Whole-form ranges of the defs compiled for the node (its node fns, and for graph nodes their graph and level fns).
refs: Vec<Range<usize>>Ranges of identifiers referring to the node elsewhere (call sites and value bindings).