Pull

Struct Pull 

pub struct Pull<N> { /* private fields */ }
A wrapper around a Node that enables pull evaluation across all inputs.

The implementation of Node will match the inner node type N, but with a unique implementation of Node::pull_eval.

Implementations

Source

impl<N: Node> Pull<N>

pub fn all(node: N) -> Self

Given some node, return a Pull node enabling pull evaluation across all outputs.

pub fn new(node: N, conf: EvalConf) -> Self

Given some node, return a Pull node enabling pull evaluation across some subset of the outputs.