Crate gantz_core

Crate gantz_core 

Re-exports

pub use builtin::Builtin;
pub use builtin::BuiltinSet;
pub use builtin::Builtins;
pub use builtin::FromNode;
pub use diagnostic::Diagnostic;
pub use edge::Edge;
pub use node::Node;
pub use steel;

Modules

args
The %args map: per-evaluation inputs the entrypoint caller provides to the VM, readable by any node’s expr via the ARGS global.
builtin
Builtin node provider trait and composable builtin specs.
compile
Items related to generating steel code from a gantz graph, primarily the module fn.
datum
A self-describing serde value: the bridge between node types and any self-describing representation of them.
diagnostic
Structured diagnostics extracted from compile and runtime errors, for frontends to surface against the graph (e.g. highlighting the offending node) and the emitted module source (e.g. highlighting the error span).
edge
A simple Edge type describing the outlet and inlet of source and destination nodes respectively.
graph
Provides visit() and register() fns for generic gantz graphs.
node
The primary Node abstraction and related items.
reg
Utilities for working with gantz_ca::Registry.
visit
Items related to traversing nested graphs of gantz nodes.
vm
Shared VM utilities for initializing and compiling gantz graphs.

Constants

ARGS
The ident used to represent the entrypoint args map - a read-only set of per-evaluation inputs (e.g. the firing time) the caller sets before invoking an entry fn, readable by any node’s expr.
ROOT_STATE
The ident used to represent the root state. This is the state of the top-level graph.