Structured diagnostics extracted from compile and runtime errors, for
frontends to surface against the graph (e.g. highlighting the offending
node) and the emitted module source (e.g. highlighting the error span).
The ident used to represent the entrypoint args map - a read-only set of
per-evaluation inputs (e.g. the firing time) the caller sets before invoking
an entry fn, readable by any node’s expr.