pub fn parse(name: &str) -> Option<Name>Expand description
Parse an emitted identifier back to the entity it names.
Returns None for identifiers the compiler did not generate from a graph
entity (params, temporaries like %vals-*/%lvl-*, user identifiers).