pub struct Pull<N> { /* private fields */ }Expand description
A wrapper around a Node that enables pull evaluation across all inputs.
The implementation of Node will match the inner node type N, but with a
unique implementation of Node::pull_eval.
Implementations